@@ -5,7 +5,7 @@ require 5.006_000;
 
 # Keep this < 1.00, so people can tell the fake
 #  mro.pm from the real one
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 BEGIN {
     # Alias our private functions over to
@@ -14,7 +14,7 @@ BEGIN {
     if($] < 5.009_005) {
         $mro::VERSION # to fool Module::Install when generating META.yml
             = $VERSION;
-        $INC{'mro.pm'} = 'Faked by MRO::Compat';
+        $INC{'mro.pm'} = __FILE__;
         *mro::import            = \&__import;
         *mro::get_linear_isa    = \&__get_linear_isa;
         *mro::set_mro           = \&__set_mro;
